// B站相关功能
export const bilibiliCollector = {
  // 获取B站HTML
  getHTML: async function(tab) {
    try {
      const result = await chrome.scripting.executeScript({
        target: { tabId: tab.id },
        function: () => {
          // 获取账号信息
          const accountInfo = {
            follow: document.querySelector('.n-statistics .n-data:nth-child(1) .n-data-v')?.textContent.trim() || '0',
            fans: document.querySelector('.n-statistics .n-data:nth-child(2) .n-data-v')?.textContent.trim() || '0',
            likes: document.querySelector('.n-statistics .n-data:nth-child(3) .n-data-v')?.textContent.trim() || '0',
            username: document.querySelector('.h-name')?.textContent.trim() || '',
            userid: document.querySelector('.h-uid')?.textContent.replace('UID:', '').trim() || '',
            ip: document.querySelector('.h-location')?.textContent.trim() || ''
          };

          // 获取视频列表
          const targetDivs = document.querySelectorAll('.video-list .small-item');
          if (targetDivs.length > 0) {
            return {
              html: Array.from(targetDivs).map(div => div.outerHTML).join(''),
              accountInfo,
              data: Array.from(targetDivs).map(item => {
                // 获取视频链接和标题
                const link = item.querySelector('a.title');
                const url = link?.href || '';
                const title = link?.textContent.trim() || '';
                            
                // 获取播放量
                const playCount = item.querySelector('.play span')?.textContent.trim() || '0';
                
                return {
                  text: title,
                  url: url,
                  likes: playCount
                };
              })
            };
          }
          return null;
        }
      });

      console.log('B站数据:', result[0].result);
      return result[0].result;
    } catch (error) {
      console.error('B站数据获取错误:', error);
      throw new Error('获取B站视频页面失败');
    }
  },

  // 自动滚动浏览
  autoScroll: async function(tab) {
    try {
      const result = await chrome.scripting.executeScript({
        target: { tabId: tab.id },
        function: () => {
          return new Promise((resolve) => {
            let scrollAttempts = 0;
            const maxAttempts = 100;
            let lastHeight = 0;
            let noChangeCount = 0;
            const maxNoChange = 5;
            let allData = new Set(); // 使用Set来存储所有数据，避免重复

            function collectData() {
              const accountInfo = {
                follow: document.querySelector('.n-statistics .n-data:nth-child(1) .n-data-v')?.textContent.trim() || '0',
                fans: document.querySelector('.n-statistics .n-data:nth-child(2) .n-data-v')?.textContent.trim() || '0',
                likes: document.querySelector('.n-statistics .n-data:nth-child(3) .n-data-v')?.textContent.trim() || '0',
                username: document.querySelector('.h-name')?.textContent.trim() || '',
                userid: document.querySelector('.h-uid')?.textContent.replace('UID:', '').trim() || '',
                ip: document.querySelector('.h-location')?.textContent.trim() || ''
              };

              // 获取当前可见的所有视频
              const items = document.querySelectorAll('.video-list .small-item');
              const currentData = Array.from(items).map(item => {
                const link = item.querySelector('a.title');
                const url = link?.href || '';
                const title = link?.textContent.trim() || '';
                const playCount = item.querySelector('.play span')?.textContent.trim() || '0';
                
                return { text: title, url, likes: playCount };
              });

              // 将新数据添加到Set中
              currentData.forEach(item => {
                if (item.url) { // 只添加有URL的数据
                  allData.add(JSON.stringify(item));
                }
              });

              return {
                accountInfo,
                data: Array.from(allData).map(item => JSON.parse(item)),
                html: Array.from(items).map(div => div.outerHTML).join('')
              };
            }

            function autoScroll() {
              // 修改滚动逻辑，每次滚动一个较小的距离
              const scrollStep = 800; // 每次滚动800像素
              const currentScroll = window.pageYOffset;
              window.scrollTo({
                top: currentScroll + scrollStep,
                behavior: 'smooth'
              });
              
              scrollAttempts++;
              
              setTimeout(() => {
                const collectedData = collectData();
                const currentHeight = document.body.scrollHeight;
                console.log('当前滚动位置:', window.pageYOffset);
                console.log('当前高度:', currentHeight, '上次高度:', lastHeight);
                console.log('累计数据条数:', collectedData.data.length);
                
                // 检查是否到达底部
                const isAtBottom = window.innerHeight + window.pageYOffset >= currentHeight - 100;
                
                if (currentHeight === lastHeight) {
                  noChangeCount++;
                } else {
                  noChangeCount = 0;
                }

                if (scrollAttempts >= maxAttempts || noChangeCount >= maxNoChange || isAtBottom) {
                  console.log('滚动结束，总条数:', collectedData.data.length);
                  resolve({
                    hasData: collectedData.data.length > 0,
                    count: collectedData.data.length,
                    message: '浏览完成',
                    collectedData
                  });
                  return;
                }

                lastHeight = currentHeight;
                // 给页面一些时间加载新内容
                setTimeout(autoScroll, 1000);
              }, 1000);
            }
            
            console.log('开始自动滚动');
            autoScroll();
          });
        }
      });
      return result[0].result;
    } catch (error) {
      throw new Error('自动浏览失败');
    }
  },

  // 导出数据到Excel
  exportToExcel: async function(content, videoCount, originalUrl) {
    try {
      const fileName = `${content.accountInfo.username}_B站_${new Date().toLocaleDateString()}`;

      // 准备Excel数据
      const rows = [
        [`${content.accountInfo.username}|${content.accountInfo.userid}，粉丝：${content.accountInfo.fans}，获赞：${content.accountInfo.likes}，关注：${content.accountInfo.follow}，${content.accountInfo.ip}，视频数：${videoCount}，主页：${originalUrl}`],
        ['标题', '链接', '播放量']
      ];

      content.data.forEach(item => {
        rows.push([item.text, item.url, item.likes]);
      });

      const csvContent = rows
        .map(row =>
          row.map(cell =>
            typeof cell === 'string' && (cell.includes(',') || cell.includes('\n') || cell.includes('"'))
              ? `"${cell.replace(/"/g, '""')}"`
              : cell
          ).join(',')
        )
        .join('\n');

      const blob = new Blob(['\ufeff' + csvContent], {
        type: 'text/csv;charset=utf-8;'
      });

      return {
        blob,
        fileName: `${fileName}.csv`
      };
    } catch (error) {
      console.error('导出错误:', error);
      throw new Error('导出失败，请重试');
    }
  }
}; 