// 抖音相关功能
export const douyinCollector = {
  // 获取抖音HTML
  getHTML: async function (tab) {
    try {
      const result = await chrome.scripting.executeScript({
        target: { tabId: tab.id },
        function: () => {
          const accountInfo = {
            follow: document.querySelector('[data-e2e="user-info-follow"] .C1cxu0Vq')?.textContent.trim() || '0',
            fans: document.querySelector('[data-e2e="user-info-fans"] .C1cxu0Vq')?.textContent.trim() || '0',
            likes: document.querySelector('[data-e2e="user-info-like"] .C1cxu0Vq')?.textContent.trim() || '0',
            username: document.querySelector('.arnSiSbK')?.textContent.trim() || '',
            userid: document.querySelector('.OcCvtZ2a')?.textContent.trim() || '',
            ip: document.querySelector('.DtUnx4ER')?.textContent.trim() || ''
          };

          const targetDiv = document.querySelector('div.pCVdP6Bb');
          if (targetDiv) {
            return {
              html: targetDiv.outerHTML,
              accountInfo,
              data: Array.from(targetDiv.querySelectorAll('a')).map(link => {
                // 查找并移除点赞元素
                const likeElement = link.querySelector('[class*="like"], [class*="heart"]');
                let likeCount = '0';
                if (likeElement) {
                  // 获取原始文本
                  const originalText = likeElement.textContent.trim();

                  // 处理点赞数
                  if (originalText) {
                    if (originalText.includes('万')) {
                      // 处理带"万"的数字
                      const num = parseFloat(originalText.replace(/[^0-9.]/g, ''));
                      likeCount = String(Math.round(num * 10000)); // 转换为实际数字
                    } else {
                      // 处理普通数字
                      likeCount = originalText.replace(/[^0-9]/g, '');
                    }

                    // 确保是有效数字
                    if (!likeCount || isNaN(likeCount)) {
                      likeCount = '0';
                    }
                  }

                  // 从DOM中临时移除点赞元素
                  likeElement.remove();
                }

                // 获取不包含点赞数的纯标题文本
                const titleText = link.textContent
                  .replace(/\d+$/, '')        // 移除末尾的数字
                  .replace(/置顶/g, '')       // 移除"置顶"文字
                  .replace(/\s+/g, ' ')       // 规范化空格
                  .trim();                    // 移除首尾空格

                // 如果之前移除了点赞元素，现在重新添加回去
                if (likeElement && link.parentNode) {
                  link.appendChild(likeElement);
                }

                return {
                  text: titleText,
                  url: link.href,
                  likes: likeCount
                };
              })
            };
          }
          return null;
        }
      });

      // 打印结果以便调试
      console.log('抖音数据:', result[0].result);
      return result[0].result;
    } catch (error) {
      console.error('抖音数据获取错误:', error);
      throw new Error('获取抖音视频页面失败');
    }
  },

  // 自动滚动浏览
  autoScroll: async function (tab) {
    try {
      const result = await chrome.scripting.executeScript({
        target: { tabId: tab.id },
        function: () => {
          return new Promise((resolve) => {
            let scrollAttempts = 0;
            const maxAttempts = 100;
            let scrollTimeout;

            // 防抖动的滚动函数
            function debouncedScroll(scrollContainer) {
              if (scrollTimeout) {
                clearTimeout(scrollTimeout);
              }
              scrollTimeout = setTimeout(() => {
                scrollContainer.scrollTop = scrollContainer.scrollHeight;
              }, 100);
            }

            function autoScroll() {
              const scrollContainer = document.querySelector('.scroll-container') ||
                document.querySelector('.table-container') ||
                document.querySelector('.ant-table-body') ||
                document.querySelector('[class*="scroll"]') ||
                document.querySelector('[class*="table"]');

              if (!scrollContainer) {
                resolve({ hasData: false, message: '未找到视频容器' });
                return;
              }

              debouncedScroll(scrollContainer);
              scrollAttempts++;

              setTimeout(() => {
                if (scrollAttempts >= maxAttempts ||
                  scrollContainer.scrollTop + scrollContainer.clientHeight >= scrollContainer.scrollHeight) {
                  const links = document.querySelectorAll('div.pCVdP6Bb a');
                  resolve({
                    hasData: true,
                    count: links.length,
                    message: '浏览完成'
                  });
                  return;
                }
                autoScroll();
              }, 1500);
            }
            autoScroll();
          });
        }
      });
      return result[0].result;
    } catch (error) {
      throw new Error('自动浏览失败');
    }
  },

  // 导出数据到Excel
  exportToExcel: async function (content, videoCount, tab, originalUrl) {
    try {
      // 获取当前标题作为文件名
      const [titleResult] = await chrome.scripting.executeScript({
        target: { tabId: tab.id },
        function: () => {
          const titleElement = document.querySelector('.arnSiSbK');
          return titleElement ? titleElement.textContent.trim() : '';
        }
      });

      // 处理文件名，移除不合法字符
      const fileName = titleResult.result
        ? titleResult.result.replace(/[\\/:*?"<>|]/g, '_').substring(0, 50)
        : `抖音数据_${new Date().toLocaleDateString()}`;

      // 准备Excel数据
      const rows = [
        // 添加账号信息作为第一行
        [`${content.accountInfo.username}|${content.accountInfo.userid}，粉丝：${content.accountInfo.fans}，获赞：${content.accountInfo.likes}，关注：${content.accountInfo.follow}，${content.accountInfo.ip}，视频数：${videoCount}，主页：${originalUrl}`],
        ['标题', '链接', '点赞数']
      ];

      // 添加数据行
      content.data.forEach(item => {
        rows.push([
          item.text,
          item.url,
          item.likes
        ]);
      });

      // 生成CSV内容
      const csvContent = rows
        .map(row =>
          row.map(cell =>
            typeof cell === 'string' && (cell.includes(',') || cell.includes('\n') || cell.includes('"'))
              ? `"${cell.replace(/"/g, '""')}"`
              : cell
          ).join(',')
        )
        .join('\n');

      // 添加BOM以支持中文
      const blob = new Blob(['\ufeff' + csvContent], {
        type: 'text/csv;charset=utf-8;'
      });

      return {
        blob,
        fileName: `${fileName}_抖音_${new Date().toLocaleDateString()}.csv`
      };
    } catch (error) {
      console.error('导出错误:', error);
      throw new Error('导出失败，请重试');
    }
  }
}; 