// 小红书相关功能
export const xiaohongshuCollector = {
  // 获取小红书HTML
  getHTML: async function(tab) {
    try {
      const result = await chrome.scripting.executeScript({
        target: { tabId: tab.id },
        function: () => {
          // 获取账号信息
          const userInteractions = document.querySelector('.user-interactions');
          const interactions = userInteractions ? Array.from(userInteractions.children) : [];
          
          const accountInfo = {
            follow: interactions[0]?.querySelector('.count')?.textContent.trim() || '0',
            fans: interactions[1]?.querySelector('.count')?.textContent.trim() || '0',
            likes: interactions[2]?.querySelector('.count')?.textContent.trim() || '0',
            username: document.querySelector('.user-name')?.textContent.trim() || '',
            userid: document.querySelector('.user-redId')?.textContent.trim() || '',
            ip: document.querySelector('.user-IP')?.textContent.trim() || ''
          };

          // 获取视频列表
          const targetDivs = document.querySelectorAll('section.note-item');
          if (targetDivs.length > 0) {
            return {
              html: Array.from(targetDivs).map(div => div.outerHTML).join(''),
              accountInfo,
              data: Array.from(targetDivs).map(item => {
                // 获取视频链接 - 使用 a.cover
                const link = item.querySelector('a.cover');
                const url = link?.href || '';

                // 获取标题和点赞数
                const title = item.querySelector('.footer .title')?.textContent.trim() || '';
                            
                // 获取点赞数
                const likeElement = item.querySelector('.like-wrapper.like-active .count');
                let likes = '0';
                if (likeElement) {
                  const likeText = likeElement.textContent.trim();
                  const numericMatch = likeText.match(/\d+/);
                  likes = numericMatch ? numericMatch[0] : likeText;
                }
                
                return {
                  text: title,
                  url: url,
                  likes: likes
                };
              })
            };
          }
          return null;
        }
      });

      console.log('小红书数据:', result[0].result);
      return result[0].result;
    } catch (error) {
      console.error('小红书数据获取错误:', error);
      throw new Error('获取小红书视频页面失败');
    }
  },

  // 自动滚动浏览并收集数据
  autoScroll: async function(tab) {
    try {
      const result = await chrome.scripting.executeScript({
        target: { tabId: tab.id },
        function: () => {
          return new Promise((resolve) => {
            let scrollAttempts = 0;
            const maxAttempts = 100;
            let lastHeight = 0;
            let noChangeCount = 0;
            const maxNoChange = 5;
            let allData = new Set();

            function collectData() {
              const userInteractions = document.querySelector('.user-interactions');
              const interactions = userInteractions ? Array.from(userInteractions.children) : [];
              
              const accountInfo = {
                follow: interactions[0]?.querySelector('.count')?.textContent.trim() || '0',
                fans: interactions[1]?.querySelector('.count')?.textContent.trim() || '0',
                likes: interactions[2]?.querySelector('.count')?.textContent.trim() || '0',
                username: document.querySelector('.user-name')?.textContent.trim() || '',
                userid: document.querySelector('.user-redId')?.textContent.trim() || '',
                ip: document.querySelector('.user-IP')?.textContent.trim() || ''
              };

              // 获取当前可见的所有笔记
              const items = document.querySelectorAll('section.note-item');
              const currentData = Array.from(items).map(item => {
                const link = item.querySelector('a.cover');
                const url = link?.href || '';
                const title = item.querySelector('.footer .title')?.textContent.trim() || '';
                            
                const likeElement = item.querySelector('.like-wrapper.like-active .count');
                let likes = '0';
                if (likeElement) {
                  const likeText = likeElement.textContent.trim();
                  const numericMatch = likeText.match(/\d+/);
                  likes = numericMatch ? numericMatch[0] : likeText;
                }
                
                return { text: title, url, likes };
              });

              currentData.forEach(item => {
                if (item.url) {
                  allData.add(JSON.stringify(item));
                }
              });

              return {
                accountInfo,
                data: Array.from(allData).map(item => JSON.parse(item)),
                html: Array.from(items).map(div => div.outerHTML).join('')
              };
            }

            function autoScroll() {
              // 先收集当前页面的数据
              const collectedData = collectData();
              console.log('本次收集数据条数:', collectedData.data.length);

              // 获取当前滚动位置
              const currentScroll = window.pageYOffset;
              // 每次滚动800像素
              window.scrollTo({
                top: currentScroll + 800,
                behavior: 'smooth'
              });
              
              scrollAttempts++;

              setTimeout(() => {
                const currentHeight = document.body.scrollHeight;
                console.log('当前高度:', currentHeight, '上次高度:', lastHeight);
                console.log('累计数据条数:', collectedData.data.length);

                if (currentHeight === lastHeight) {
                  noChangeCount++;
                } else {
                  noChangeCount = 0;
                }

                // 检查是否到达底部
                const isAtBottom = window.innerHeight + window.pageYOffset >= currentHeight - 100;
                if (scrollAttempts >= maxAttempts || noChangeCount >= maxNoChange || isAtBottom) {
                  console.log('滚动结束，总条数:', collectedData.data.length);
                  resolve({
                    hasData: collectedData.data.length > 0,
                    count: collectedData.data.length,
                    message: '浏览完成',
                    collectedData
                  });
                  return;
                }

                lastHeight = currentHeight;
                setTimeout(autoScroll, 1000);
              }, 1000);
            }

            console.log('开始自动滚动');
            autoScroll();
          });
        }
      });
      return result[0].result;
    } catch (error) {
      throw new Error('自动浏览失败');
    }
  },

  // 导出数据到Excel
  exportToExcel: async function(content, videoCount, originalUrl) {
    try {
      const fileName = `${content.accountInfo.username}_小红书_${new Date().toLocaleDateString()}`;

      // 准备Excel数据
      const rows = [
        [`${content.accountInfo.username}|${content.accountInfo.userid}，粉丝：${content.accountInfo.fans}，获赞：${content.accountInfo.likes}，关注：${content.accountInfo.follow}，${content.accountInfo.ip}，笔记数：${videoCount}，主页：${originalUrl}`],
        ['标题', '链接', '点赞数']
      ];

      content.data.forEach(item => {
        rows.push([item.text, item.url, item.likes]);
      });

      const csvContent = rows
        .map(row =>
          row.map(cell =>
            typeof cell === 'string' && (cell.includes(',') || cell.includes('\n') || cell.includes('"'))
              ? `"${cell.replace(/"/g, '""')}"`
              : cell
          ).join(',')
        )
        .join('\n');

      const blob = new Blob(['\ufeff' + csvContent], {
        type: 'text/csv;charset=utf-8;'
      });

      return {
        blob,
        fileName: `${fileName}.csv`
      };
    } catch (error) {
      console.error('导出错误:', error);
      throw new Error('导出失败，请重试');
    }
  }
}; 